@@ -1,5 +1,5 @@
-package Fair::Profile::SerializableProperty;
-$Fair::Profile::SerializableProperty::VERSION = '0.21';
+package FAIR::Profile::SerializableProperty;
+$FAIR::Profile::SerializableProperty::VERSION = '0.215';
 
 # ABSTRACT: a moose role that indicates that a certain property is intended to become part of the RDF serialization of the FAIR Profile.  All other properties are "utility" properties of the object
 
@@ -24,11 +24,11 @@ __END__
 
 =head1 NAME
 
-Fair::Profile::SerializableProperty - a moose role that indicates that a certain property is intended to become part of the RDF serialization of the FAIR Profile.  All other properties are "utility" properties of the object
+FAIR::Profile::SerializableProperty - a moose role that indicates that a certain property is intended to become part of the RDF serialization of the FAIR Profile.  All other properties are "utility" properties of the object
 
 =head1 VERSION
 
-version 0.21
+version 0.215
 
 =head1 AUTHOR
 
